==> phpwebthings-0.6.0.zip: phpwebthings-0.6.0/modules/forum/lang/msg_ptbr.php <==
<?php
// lang file for forums by Paulo Assis <paulo@coral.srv.br>

$lang["FORUM_TITLE"]="Frums";
$lang["FORUM_HEADER_TITLE"]="Ttulo";
$lang["FORUM_HEADER_TOPICS"]="Tpicos";
$lang["FORUM_HEADER_POSTS"]="Msgs";
$lang["FORUM_HEADER_LASTPOST"]="ltima msg";
$lang["FORUM_HEADER_VR"]="Exib/Resp";
$lang["FORUM_BY"]="por";
$lang["FORUM_WROTE"]="escreveu em";
$lang["FORUM_POSTED"]="Enviada em";
$lang["FORUM_QUOTE"]="<img src=\"modules/forum/images/quote_enus.gif\" alt=\"Quote Message\" border=\"0\">";
$lang["FORUM_TEXT"]="Mensagem";
$lang["FORUM_SEND"]="Enviar mensagem";
$lang["FORUM_POST"]="Enviar uma mensagem";
$lang["FORUM_NOT_LOGGED"]="Desculpe, mas voc precisa se logar para enviar uma mensagem no frum. Se voc no tem um login, porque no se registra?  de graa!";
$lang["FORUM_NOT_LOGGED2"]="Voc poderia enviar uma mensagem para o frum se estivesse registrado. Se voc no tem um login, porque no se registra?  de graa!";
$lang["FORUM_SEARCH"]="Procurar";
$lang["FORUM_FOUND"]="mensagens encontradas";
$lang["FORUM_LOCKED"]="<i>(F&oacute;rum bloqueado)</i>";
$lang["FORUM_CLOSED"]="<i>(Discusso fechada)</i>";
$lang["FORUM_PARSE"]="Habilita tags WT?";
$lang["FORUM_PREVIOUS"]="Anterior";
$lang["FORUM_NEXT"]="Prximo";
$lang["FORUM_NOUSER"]="*nobody*";
$lang["FORUM_EDIT"]="editar";
$lang["FORUM_GOUP"]="Voltar";
$lang["FORUM_ERROR_01"]="Voc precisa informar o ttulo e mensagem.";
$lang["FORUM_MSG_POSTED"]= "Sua mensagem foi enviada!";
$lang["FORUM_MSG_OPTION1"]= "Voltar ao frum";
$lang["FORUM_MSG_OPTION2"]= "Ver a mensagem que voc postou";
?>

==> phpwebthings-1.0.zip: phpwebthings-1.0/modules/forum/lang/msg_ptbr.php <==
<?php
// lang file for forums by Paulo Assis <paulo@coral.srv.br>

$lang["FORUM_TITLE"]="Frums";
$lang["FORUM_HEADER_TITLE"]="Ttulo";
$lang["FORUM_HEADER_TOPICS"]="Tpicos";
$lang["FORUM_HEADER_POSTS"]="Msgs";
$lang["FORUM_HEADER_LASTPOST"]="ltima msg";
$lang["FORUM_HEADER_VR"]="Exib/Resp";
$lang["FORUM_BY"]="por";
$lang["FORUM_WROTE"]="escreveu em";
$lang["FORUM_POSTED"]="Enviada em";
$lang["FORUM_QUOTE"]="<img src=\"modules/forum/images/quote_enus.gif\" alt=\"Quote Message\" border=\"0\">";
$lang["FORUM_TEXT"]="Mensagem";
$lang["FORUM_SEND"]="Enviar mensagem";
$lang["FORUM_POST"]="Enviar uma mensagem";
$lang["FORUM_NOT_LOGGED"]="Desculpe, mas voc precisa se logar para enviar uma mensagem no frum. Se voc no tem um login, porque no se registra?  de graa!";
$lang["FORUM_NOT_LOGGED2"]="Voc poderia enviar uma mensagem para o frum se estivesse registrado. Se voc no tem um login, porque no se registra?  de graa!";
$lang["FORUM_SEARCH"]="Procurar";
$lang["FORUM_FOUND"]="mensagens encontradas";
$lang["FORUM_LOCKED"]="<i>(F&oacute;rum bloqueado)</i>";
$lang["FORUM_CLOSED"]="<i>(Discusso fechada)</i>";
$lang["FORUM_PARSE"]="Habilita tags WT?";
$lang["FORUM_PREVIOUS"]="Anterior";
$lang["FORUM_NEXT"]="Prximo";
$lang["FORUM_NOUSER"]="*nobody*";
$lang["FORUM_EDIT"]="editar";
$lang["FORUM_GOUP"]="Voltar";
$lang["FORUM_ERROR_01"]="Voc precisa informar o ttulo e mensagem.";
$lang["FORUM_MSG_POSTED"]= "Sua mensagem foi enviada!";
$lang["FORUM_MSG_OPTION1"]= "Voltar ao frum";
$lang["FORUM_MSG_OPTION2"]= "Ver a mensagem que voc postou";
$lang["FORUM_EDIT_TOPIC_TITLE"]="Tpicos do frum";
$lang["FORUM_EDIT_ACCESS_TITLE"]="Moderadores do frum";
?>
